==> lubuntu-installer-prompt_1.1.0.orig.tar.gz: installer-prompt-1.1.0/src/translations/lubuntu-installer-prompt_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>InstallerPrompt</name>
    <message>
        <location filename="../installerprompt.ui" line="20"/>
        <source>Try or Install Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="207"/>
        <source>Select Your Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="284"/>
        <source>Select a Wi-Fi Network:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="329"/>
        <location filename="../installerprompt.cpp" line="186"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="371"/>
        <source>(For advanced network configuration, select &quot;Try Lubuntu&quot;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Try Lubuntu without installing it on your system. Allows you to use programs, browse the Web, and even temporarily install apps without modifying your system. Changes made within the live environment will be lost when the computer shuts down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="480"/>
        <source>  Try Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="542"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Install Lubuntu onto your system. You can install Lubuntu by itself, or alongside an existing operating system.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="553"/>
        <source>  Install Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="684"/>
        <source>Connection Status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="28"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="28"/>
        <source>Background image cannot be loaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="81"/>
        <source>Not Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="86"/>
        <source>Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="90"/>
        <source>Connecting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="94"/>
        <source>Disconnecting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="98"/>
        <source>Unknown Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="179"/>
        <source>Enter Wi-Fi Password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="182"/>
        <source>Wrong Wi-Fi password for %1. Try again:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="237"/>
        <source>Connection Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="237"/>
        <source>Unable to connect to the network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="303"/>
        <source>WiFi Not Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="303"/>
        <source>No WiFi devices were found on this system.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lubuntu-installer-prompt_1.1.2.orig.tar.gz: installer-prompt-1.1.2/src/translations/lubuntu-installer-prompt_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>InstallerPrompt</name>
    <message>
        <location filename="../installerprompt.ui" line="20"/>
        <source>Try or Install Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="237"/>
        <source>Select Your Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="263"/>
        <source>✅ Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="280"/>
        <source>You entered an incorrect password. Please try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="320"/>
        <source>Select a Wi-Fi Network:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="205"/>
        <source>Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="380"/>
        <source>(For advanced network configuration, select &quot;Try Lubuntu&quot;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="419"/>
        <source>✅ Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="433"/>
        <location filename="../installerprompt.cpp" line="475"/>
        <source>Changing language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="525"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Try Lubuntu without installing it on your system. Allows you to use programs, browse the Web, and even temporarily install apps without modifying your system. Changes made within the live environment will be lost when the computer shuts down.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="539"/>
        <source>  Try Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="589"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Install Lubuntu onto your system. You can install Lubuntu by itself, or alongside an existing operating system.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="600"/>
        <source>  Install Lubuntu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="49"/>
        <location filename="../installerprompt.cpp" line="256"/>
        <location filename="../installerprompt.cpp" line="271"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="49"/>
        <source>Background image cannot be loaded.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="108"/>
        <source>Not Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="194"/>
        <source>Wi-Fi Password Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="203"/>
        <source>Enter password for &quot;%1&quot;:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="256"/>
        <source>Failed to create Wi-Fi settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="271"/>
        <source>Failed to add Wi-Fi connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="472"/>
        <source>Unable to download full language support, changing anyway...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.ui" line="727"/>
        <location filename="../installerprompt.cpp" line="114"/>
        <source>Connected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="119"/>
        <source>Connecting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="124"/>
        <source>Disconnecting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="130"/>
        <source>Unknown Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="330"/>
        <source>WiFi Not Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../installerprompt.cpp" line="330"/>
        <source>No WiFi devices were found on this system.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
